@@ -9,17 +9,25 @@ gridded(meuse.grid) =~ x+y
 # Ordinary kriging
 kriging_result = autoKrige(zinc~1, meuse, meuse.grid)
 summary(kriging_result)
+pos = posPredictionInterval(kriging_result, 95, 75)
+summary(pos)
 
 kriging_result = autoKrige(zinc~1, meuse, meuse.grid, fix.values = c(0.2,NA,NA))
 summary(kriging_result)
+pos = posPredictionInterval(kriging_result, 95, 75)
+summary(pos)
 
 # Universal kriging
 kriging_result = autoKrige(zinc~soil+ffreq+dist, meuse, meuse.grid)
 summary(kriging_result)
+pos = posPredictionInterval(kriging_result, 95, 75)
+summary(pos)
 
 # Block kriging
 kriging_result = autoKrige(zinc~soil+ffreq+dist, meuse, meuse.grid, block = c(400,400))
 summary(kriging_result)
+pos = posPredictionInterval(kriging_result, 95, 75)
+summary(pos)
 
 # Kriging with power model
 kriging_result = autoKrige(zinc~soil+ffreq+dist, meuse, meuse.grid, model = "Pow")
